Software Heritage Datasets
==========================

This page lists the different public datasets and periodic data dumps of the
archive produced and released by `Software Heritage`_.

If you need help accessing our data, please send an email to
`datasets@softwareheritage.org <mailto:datasets@softwareheritage.org>`_.

.. _Software Heritage: https://www.softwareheritage.org
